@@ -35,13 +35,14 @@ class AioDispatchClient(object):
         }
 
         with await self.pool as conn:
-            timeout -= (datetime.utcnow() - begin)
-            if timeout > 0:
+            timeout -= (datetime.utcnow() - begin).total_seconds()
+
+            if int(timeout) > 0:
                 # with await self.pool as conn:  # low-level redis connection
                 await conn.execute(b'RPUSH', service_queue, json.dumps(request, ensure_ascii=False))
-                timeout -= (datetime.utcnow() - begin)
-                if timeout > 0:
-                    result = await conn.execute(b'BLPOP', reply_to, timeout)
+                timeout -= (datetime.utcnow() - begin).total_seconds()
+                if int(timeout) > 0:
+                    result = await conn.execute(b'BLPOP', reply_to, int(timeout))
                     if result and result[0] == reply_to:
                         response = DispatchResponseModel.parse_obj(json.loads(result[1]))
                         if response.correlation_id == correlation_id:
